==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/mediabox/lang/mediabox_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mediabox?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reiniciar',
	'boxstr_close' => 'Fechar',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Seguinte',
	'boxstr_previous' => 'Anterior',
	'boxstr_slideshowStart' => 'Slideshow',
	'boxstr_slideshowStop' => 'Parar',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Indique o elemento alvo que irá desencadear a caixa. (Expressão CSS ou jQuery)',
	'explication_selecteur_galerie' => 'Indique os elementos alvo para agrupar numa galeria. (Expressão CSS ou jQuery)',
	'explication_splash_url' => 'Indique o URL do conteúdo multimédia a exibir numa caixa na primeira visita ao sítio público.',
	'explication_traiter_toutes_images' => 'Inserir uma caixa em volta de todas as imagens?',

	// L
	'label_active' => 'Activar a mediabox no sítio público',
	'label_apparence' => 'Aspecto',
	'label_aucun_style' => 'Não usar nenhuma moldura por defeito',
	'label_choix_transition_elastic' => 'Elástico',
	'label_choix_transition_fade' => 'Desvanecimento',
	'label_choix_transition_none' => 'Sem efeito de transição',
	'label_maxheight' => 'Altura máxima (% ou px)',
	'label_maxwidth' => 'Largura máxima (% ou px)',
	'label_minheight' => 'Altura mínima (% ou px)',
	'label_minwidth' => 'Largura mínima (% ou px)',
	'label_opacite' => 'Opacidade do fundo',
	'label_selecteur_commun' => 'Em geral',
	'label_selecteur_galerie' => 'Em modo galeria',
	'label_skin' => 'Aspecto visual',
	'label_slideshow_speed' => 'Tempo de exibição das fotos do slideshow (ms)',
	'label_speed' => 'Velocidade de transição (ms)',
	'label_splash' => 'Caixa Splash ',
	'label_splash_url' => 'URL a exibir',
	'label_traiter_toutes_images' => 'Imagens',
	'label_transition' => 'Transição entre duas visualizações',

	// T
	'titre_menu_box' => 'Media Box',
	'titre_page_configurer_box' => 'Configuração da Media Box'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/mediabox/lang/mediabox_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mediabox?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Reiniciar',
	'boxstr_close' => 'Fechar',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Seguinte',
	'boxstr_previous' => 'Anterior',
	'boxstr_slideshowStart' => 'Slideshow',
	'boxstr_slideshowStop' => 'Parar',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Indique o elemento alvo que irá desencadear a caixa. (Expressão CSS ou jQuery)',
	'explication_selecteur_galerie' => 'Indique os elementos alvo para agrupar numa galeria. (Expressão CSS ou jQuery)',
	'explication_splash_url' => 'Indique o URL do conteúdo multimédia a exibir numa caixa na primeira visita ao sítio público.',
	'explication_traiter_toutes_images' => 'Inserir uma caixa em volta de todas as imagens?',

	// L
	'label_active' => 'Activar a mediabox no sítio público',
	'label_apparence' => 'Aspecto',
	'label_aucun_style' => 'Não usar nenhuma moldura por defeito',
	'label_choix_transition_elastic' => 'Elástico',
	'label_choix_transition_fade' => 'Desvanecimento',
	'label_choix_transition_none' => 'Sem efeito de transição',
	'label_maxheight' => 'Altura máxima (% ou px)',
	'label_maxwidth' => 'Largura máxima (% ou px)',
	'label_minheight' => 'Altura mínima (% ou px)',
	'label_minwidth' => 'Largura mínima (% ou px)',
	'label_opacite' => 'Opacidade do fundo',
	'label_selecteur_commun' => 'Em geral',
	'label_selecteur_galerie' => 'Em modo galeria',
	'label_skin' => 'Aspecto visual',
	'label_slideshow_speed' => 'Tempo de exibição das fotos do slideshow (ms)',
	'label_speed' => 'Velocidade de transição (ms)',
	'label_splash' => 'Caixa Splash ',
	'label_splash_height' => 'Altura (% ou px)',
	'label_splash_url' => 'URL a exibir',
	'label_splash_width' => 'Largura (% ou px)',
	'label_traiter_toutes_images' => 'Imagens',
	'label_transition' => 'Transição entre duas visualizações',

	// T
	'titre_menu_box' => 'Media Box',
	'titre_page_configurer_box' => 'Configuração da Media Box'
);

?>
